import * as React from 'react';
import {Layout, Providers} from '@rx-suite/ui';
import './stores';
import {RxAppModel, RxAppStore} from '@rx-suite/stores';
import {getRoutes} from "./routes";
import 'react-table/react-table.css';
import 'react-table-hoc-fixed-columns/lib/styles.css'
import 'react-grid-layout/css/styles.css'
import 'react-resizable/css/styles.css'
import {observer} from "mobx-react-lite";
import {subscribe} from "@rx-suite/data";
import {t} from "@lingui/macro";
import {LinearProgress} from "@material-ui/core";
import {DashboardTargetStore} from "./stores/DashboardTargetStore";
import {DashboardComponentStore} from "./stores/DashboardComponentStore";
import {DashboardComponentPlacementStore} from "./stores/DashboardComponentPlacementStore";
import {DashboardStore} from "./stores/DashboardStore";
import {DashboardGroupDashboardStore} from "./stores/DashboardGroupDashboardStore";
import {DashboardGroupStore} from "./stores/DashboardGroupStore";

subscribe();
DashboardTargetStore.getAll();
DashboardComponentStore.getAll();
DashboardComponentPlacementStore.getAll();
DashboardStore.getAll();
DashboardGroupDashboardStore.getAll();
DashboardGroupStore.getAll();


export default observer(() => {
    const [messages, setMessages] = React.useState<any>(null);
    const model = RxAppStore.selectedModel as RxAppModel;
    console.log(model);
    React.useEffect(() => {
        if (model) {
            const getMessages = async () => {
                const compiledMessages = await import(`../../../locales/${model.language}/messages.mjs`);
                setMessages(compiledMessages.messages);
            }
            model.setTitleBase(t`Rx-Dashboards`);
            getMessages();
        }
    }, [model]);

    if (!model || !messages) {
        return <LinearProgress/>
    }
    return (
        <Providers theme={model.theme} language={model.language} messages={messages}>
            <Layout routes={getRoutes(DashboardTargetStore.models)}/>
        </Providers>
    )
});


