import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardTargetModel} from "../../../stores/DashboardTargetStore";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {ParameterField} from "./ParameterField";
import {Parameter} from "../../../stores/Types";
import {IconButton, TableCell} from "@material-ui/core";
import {ScoreCardGoalSetter} from "./display_options/ScoreCardGoalSetter";
import {ScoreCardRowParameter} from "./display_options/ScoreCardSettings";
import ClearIcon from "@material-ui/icons/Close";

export type TableRowParametersProps = {
    rowIndex: number,
    row: ScoreCardRowParameter,
    component: DashboardComponentModel,
    dashboardTarget: DashboardTargetModel | undefined,
    onDeleteRow: (rowIndex: number) => void,
}

export const ScoreCardRowParameters: React.FunctionComponent<TableRowParametersProps> = observer(({
                                                                                                      rowIndex,
                                                                                                      row,
                                                                                                      component,
                                                                                                      dashboardTarget,
                                                                                                      onDeleteRow
                                                                                                  }) => {

    const onDelete = () => {
        onDeleteRow(rowIndex);
    }

    return <React.Fragment>
        {Object.values(dashboardTarget?.parameters || {}).map((parameterDef: Parameter) => {
            if (!parameterDef.single_row_parameter) {
                return undefined;
            }
            const sub_parameters = () => {
                if (!parameterDef.sub_parameters) {
                    return undefined
                }
                return parameterDef.sub_parameters?.map(({condition, parameter}) => {
                    if (!(row[parameterDef.id] === condition)) return undefined;
                    return <ParameterField component={component}
                                           parameter={parameter}
                                           rowIndex={rowIndex}
                                           row={row}
                    />
                })
            }

            if (row.row_type == "divider" && parameterDef.id != "row_type") {
                return <TableCell style={{minWidth: '200px', maxWidth: '500px'}}/>;
            }

            return <TableCell style={{minWidth: '200px', maxWidth: '500px'}}>
                <ParameterField component={component}
                                parameter={parameterDef}
                                rowIndex={rowIndex}
                                row={row}
                />
                {sub_parameters()}
            </TableCell>
        })}
        <ScoreCardGoalSetter component={component} row={row} rowIndex={rowIndex}/>
        <TableCell><IconButton style={{color: 'red'}} onClick={onDelete}>
            <ClearIcon/>
        </IconButton></TableCell>
    </React.Fragment>
});
