import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../../stores/DashboardComponentStore";
import {Table, TableBody, TableCell, TableHead, TableRow, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {ColorTargetPicker} from "./ColorTargetPicker";

export type ColorSetterProps = {
    component: DashboardComponentModel
}

export const ColorSetter: React.FunctionComponent<ColorSetterProps> = observer(({component}) => {
    const colorTargets = component.colorTargets;
    const hasDescription = colorTargets.some(ct => ct.description);
    return <>
        <Table>
            <TableHead>
                <TableRow>
                    <TableCell>{t`Label`}</TableCell>
                    {hasDescription && <TableCell>{t`Description`}</TableCell>}
                    <TableCell>{t`Color`}</TableCell>
                </TableRow>
            </TableHead>
            <TableBody>
                {
                    colorTargets.map((ct) => {
                        return <TableRow key={ct.value}>
                            <TableCell><Typography
                                variant={'subtitle2'}>{ct.label}</Typography></TableCell>
                            {hasDescription && <TableCell><Typography
                                variant={'subtitle2'}>{ct.description || ''}</Typography></TableCell>}
                            <TableCell>
                                <ColorTargetPicker component={component} id={ct.value} name={ct.label}/>
                            </TableCell>
                        </TableRow>
                    })}
            </TableBody>
        </Table>
    </>
});