import * as React from 'react';
import {useState} from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, ModelForm, ModelInput, PaddedPaper} from "@rx-suite/ui";
import {Grid} from "@material-ui/core";
import {AddDashboardTable} from "../../components/dashboard_groups/AddDashboardTable";
import {DashboardGroupModel} from "../../stores/DashboardGroupStore";
import {NestedDashboardForm} from "../../components/dashboard_groups/NestedDashboardForm";
import {DashboardGroupDashboardList} from "../../components/dashboard_groups/DashboardGroupDashboardList";


export const DashboardGroupForm: React.FunctionComponent<FormProps> = observer(({model, readOnly}) => {
    const [formOpen, setFormOpen] = useState(false);
    const openForm = React.useCallback(() => setFormOpen(true), [setFormOpen])
    return (
        <PaddedPaper>
            <NestedDashboardForm group={model as DashboardGroupModel} open={formOpen} setOpen={setFormOpen}/>
            <ModelForm model={model} readOnly={readOnly} suppressWrapper suppressImportExport>
                <ModelInput name={"name"}/>
                <ModelInput name={"desc"} multiline rowsMax={4}/>
                <Grid container>
                    {!readOnly && <Grid item xs={6}><AddDashboardTable group={model as DashboardGroupModel}
                                                                       openForm={openForm}/></Grid>}
                    <Grid item xs={readOnly ? 12 : 6}><DashboardGroupDashboardList
                        group={model as DashboardGroupModel}/></Grid>
                </Grid>
            </ModelForm>
        </PaddedPaper>
    )
});
