import {attribute, DataStore, model, Model, Transport} from '@rx-suite/data';
import {t} from "@lingui/macro";
import * as yup from 'yup';
import {action} from "mobx";
import {Layout} from "react-grid-layout";

@model({
    transportLayer: new Transport("/api/dashboard_component_placements", "dashboard_component_placement"),
    permissionTarget: "DashboardComponent",
    routingInfo: {}
})
export class DashboardComponentPlacementModel extends Model {
    constructor() {
        super();
        super.setup();
    }

    @attribute({
        label: t`X`,
        validation: yup.number()
    })
    x = 0;

    @attribute({
        label: t`Y`,
        validation: yup.number()
    })
    y = 0;

    @attribute({
        label: t`Height`,
        validation: yup.number()
    })
    height = 120;

    @attribute({
        label: t`Width`,
        validation: yup.number()
    })
    width = 120;

    @attribute({
        label: t`Component`,
        connects: 'DashboardComponentModel',
        validation: yup.number(),
        autoTable: false
    })
    dashboard_component_id: number | undefined = undefined;

    @attribute({
        label: t`Dashboard`,
        connects: 'DashboardModel',
        validation: yup.number(),
        autoTable: false
    })
    dashboard_id: number | undefined = undefined;

    @action.bound
    handleLayoutChange(newLayout: Layout) {
        this.nestedAssignment('x', newLayout.x)
        this.nestedAssignment('y', newLayout.y)
        this.nestedAssignment('width', newLayout.w)
        this.nestedAssignment('height', newLayout.h)
    }
}

export const DashboardComponentPlacementStore = DashboardComponentPlacementModel.store as DataStore<DashboardComponentPlacementModel>;
DashboardComponentPlacementStore.setFetchParams({limit: undefined, page: 0, sorted: [], filtered: []});
