# == Schema Information
#
# Table name: lab_layouts
#
#  id         :bigint           not null, primary key
#  name       :string
#  created_at :datetime         not null
#  updated_at :datetime         not null
#
class LabLayout < ApplicationRecord
  has_many :lab_layout_components, autosave: true, dependent: :destroy

  def update_components(components, files)
    remove_deleted_components(components)
    components.each do |c|
      if new_component?(c)
        comp = lab_layout_components.build(name: c[:name])
        case c[:component_type]
        when "machine_status_dot"
          comp.machine_sn = c[:machine_sn]
        when "image"
          file = files[c[:name]]
          comp.component_image.attach(io: file, filename: File.basename(file.path), content_type: file.content_type, identify: false) unless file.blank?
        end
      else
        comp = lab_layout_components.detect { |component| component.id == c[:id] }
      end

      next if comp.nil?

      comp.assign_attributes({
        component_type: c[:component_type],
        width: c[:width],
        height: c[:height],
        x: c[:x],
        y: c[:y],
        aspect_ratio: c[:aspect_ratio],
        z_index: c[:z_index]
      })
      comp.alert_after = c[:alert_after] if c[:component_type] == "machine_status_dot"
      comp.machine_group_ids = c[:machine_group_ids].join(",") if c[:component_type] == "alert_group"
    end
  end

  def to_json(*_args)
    render_jbuilder_partial
  end

  private

  def remove_deleted_components(components)
    lab_layout_components.each do |c|
      keep = components.detect { |comp| c.id == comp[:id] }
      unless keep
        c.mark_for_destruction
        c.component_image.purge if c.component_image&.attached?
      end
    end
  end

  def new_component?(component)
    component[:id] == -1
  end
end
